@@ -506,8 +506,7 @@ void KateFileTreeModel::initModel()
     }
 
     if (m_mainWindow) {
-        QWidgetList widgets;
-        QMetaObject::invokeMethod(m_mainWindow->window(), "widgets", Q_RETURN_ARG(QWidgetList, widgets));
+        QWidgetList widgets = m_mainWindow->widgets();
         for (auto *w : std::as_const(widgets)) {
             addWidget(w);
         }
@@ -1020,13 +1019,13 @@ void KateFileTreeModel::updateBackgrounds(bool force)
     helper.reserve(m_viewHistory.size() + m_editHistory.size());
 
     int i = 1;
-    for (ProxyItem *item : qAsConst(m_viewHistory)) {
+    for (ProxyItem *item : std::as_const(m_viewHistory)) {
         helper[item].view = i;
         i++;
     }
 
     i = 1;
-    for (ProxyItem *item : qAsConst(m_editHistory)) {
+    for (ProxyItem *item : std::as_const(m_editHistory)) {
         helper[item].edit = i;
         i++;
     }
@@ -1063,12 +1062,12 @@ void KateFileTreeModel::updateBackgrounds(bool force)
     for (const auto &[item, brush] : m_brushes) {
         oldBrushes.erase(item);
         const QModelIndex idx = createIndex(item->row(), 0, item);
-        dataChanged(idx, idx);
+        Q_EMIT dataChanged(idx, idx);
     }
 
     for (const auto &[item, brush] : oldBrushes) {
         const QModelIndex idx = createIndex(item->row(), 0, item);
-        dataChanged(idx, idx);
+        Q_EMIT dataChanged(idx, idx);
     }
 }
 
@@ -1470,9 +1469,9 @@ void KateFileTreeModel::resetHistory()
     m_editHistory.clear();
     m_brushes.clear();
 
-    for (ProxyItem *item : qAsConst(list)) {
+    for (ProxyItem *item : std::as_const(list)) {
         QModelIndex idx = createIndex(item->row(), 0, item);
-        dataChanged(idx, idx, QList<int>(1, Qt::BackgroundRole));
+        Q_EMIT dataChanged(idx, idx, QList<int>(1, Qt::BackgroundRole));
     }
 }
 
