@@ -17,6 +17,7 @@
 #include <KTextEditor/MainWindow>
 #include <KTextEditor/View>
 
+#include <QFrame>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QIdentityProxyModel>
@@ -243,6 +244,12 @@ public:
         m_symbols->setFocusPolicy(Qt::NoFocus);
         m_symbols->setLayoutDirection(Qt::LeftToRight);
         m_toolview->layout()->setContentsMargins(0, 0, 0, 0);
+
+        auto separator = new QFrame(m_toolview.get());
+        separator->setFrameShape(QFrame::HLine);
+        separator->setEnabled(false);
+        m_toolview->layout()->addWidget(separator);
+
         m_toolview->layout()->addWidget(m_symbols);
         m_toolview->layout()->setSpacing(0);
 
@@ -251,6 +258,7 @@ public:
         m_toolview->layout()->addWidget(m_filter);
         m_filter->setPlaceholderText(i18n("Filter..."));
         m_filter->setClearButtonEnabled(true);
+        m_filter->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::TopEdge}));
         connect(m_filter, &KLineEdit::textChanged, this, &self_type::filterTextChanged);
 
         m_symbols->setContextMenuPolicy(Qt::CustomContextMenu);
