@@ -9,10 +9,11 @@
 
 #include "kateproject.h"
 
+#include <QDir>
 #include <QHash>
 #include <QRunnable>
+#include <QSet>
 
-class QDir;
 class KateProjectItem;
 
 /**
@@ -65,6 +66,13 @@ private:
     static QList<QString> filesFromDarcs(const QDir &dir, bool recursive);
     static QList<QString> filesFromFossil(const QDir &dir, bool recursive);
     static QList<QString> filesFromDirectory(QDir dir, bool recursive, bool hidden, const QStringList &filters);
+    static void scanDirRec(QDir dir,
+                           const QString &baseDirPath,
+                           const QStringList &nameFilters,
+                           QDir::Filters filterFlags,
+                           bool recursive,
+                           QList<QString> &files,
+                           QSet<QString> &scannedDirs);
 
     static QList<QString> gitFiles(const QDir &dir, bool recursive, const QStringList &args);
 
