@@ -39,12 +39,10 @@
 
 #include "SingleApplication/SingleApplication"
 
-#include "config-kate.h"
-
+// X11 startup handling
+#define HAVE_X11 __has_include(<KX11Extras>)
 #if HAVE_X11
-
 #include <KX11Extras>
-
 #include <private/qtx11extras_p.h>
 #endif
 
@@ -89,7 +87,7 @@ int main(int argc, char **argv)
                          QStringLiteral(KATE_VERSION),
                          i18n("Kate - Advanced Text Editor"),
                          KAboutLicense::LGPL_V2,
-                         i18n("(c) 2000-2022 The Kate Authors"),
+                         i18n("(c) 2000-2024 The Kate Authors"),
                          // use the other text field to get our mascot into the about dialog
                          QStringLiteral("<img height=\"362\" width=\"512\" src=\":/kate/mascot.png\"/>"),
                          QStringLiteral("https://kate-editor.org"));
@@ -265,7 +263,7 @@ int main(int argc, char **argv)
         // two possibilities: pid given or not...
         if ((!force_new) && serviceName.isEmpty()) {
             if ((parser.isSet(usePidOption)) || (!qEnvironmentVariableIsEmpty("KATE_PID"))) {
-                QString usePid = (parser.isSet(usePidOption)) ? parser.value(usePidOption) : QString::fromLocal8Bit(qgetenv("KATE_PID"));
+                QString usePid = (parser.isSet(usePidOption)) ? parser.value(usePidOption) : qEnvironmentVariable("KATE_PID");
 
                 serviceName = QLatin1String("org.kde.kate-") + usePid;
                 const auto it = std::find_if(kateServices.cbegin(), kateServices.cend(), [&serviceName](const auto &instance) {
@@ -339,7 +337,7 @@ int main(int argc, char **argv)
                 QDBusMessage res = QDBusConnection::sessionBus().call(m);
                 if (res.type() == QDBusMessage::ReplyMessage) {
                     if (res.arguments().count() == 1) {
-                        QVariant v = res.arguments()[0];
+                        QVariant v = res.arguments().constFirst();
                         if (v.isValid()) {
                             QString s = v.toString();
                             if ((!s.isEmpty()) && (s != QLatin1String("ERROR"))) {
