@@ -79,7 +79,7 @@
 #include <unistd.h>
 #endif
 
-#if HAVE_DAEMON
+#ifdef HAVE_DAEMON
 #include <unistd.h>
 #endif
 
@@ -188,7 +188,6 @@ KateApp::KateApp(const QCommandLineParser &args, const ApplicationMode mode, con
     , m_adaptor(this)
     , m_docManager(this)
     , m_sessionManager(this, sessionsDir)
-    , m_stashManager(this)
     , m_lastActivationChange(QDateTime::currentMSecsSinceEpoch())
 {
     /**
