@@ -247,16 +247,9 @@ public:
     bool documentVisibleInOtherWindows(KTextEditor::Document *doc, KateMainWindow *window) const;
 
     /**
-     * some stuff for the dcop API
+     * some stuff for the DBus API
      */
 public:
-    /**
-     * checks if the current instance is in a given activity
-     * @param activity activity to check
-     * @return true if the window is in the given activity, false otherwise
-     */
-    bool isOnActivity(const QString &activity);
-
     /**
      * open url with given encoding
      * used by kate if --use given
@@ -396,6 +389,15 @@ public Q_SLOTS:
         return true;
     }
 
+    /**
+     * last time some QEvent::ActivationChange occured
+     * used to determine which instance to reuse, if we have multiple
+     */
+    qint64 lastActivationChange() const
+    {
+        return m_lastActivationChange;
+    }
+
     /**
      * A message is received from an external instance, if we use QtSingleApplication
      *
@@ -482,4 +484,10 @@ private:
      */
     KUserFeedback::Provider m_userFeedbackProvider;
 #endif
+
+    /**
+     * last time some QEvent::ActivationChange occured
+     * used to determine which instance to reuse, if we have multiple
+     */
+    qint64 m_lastActivationChange;
 };
