@@ -164,7 +164,9 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
 
     setAcceptDrops(true);
 
-    connect(KateApp::self()->sessionManager(), SIGNAL(sessionChanged()), this, SLOT(updateCaption()));
+    connect(KateApp::self()->sessionManager(), &KateSessionManager::sessionChanged, this, [this] {
+        updateCaption(nullptr);
+    });
 
     connect(this, &KateMDI::MainWindow::sigShowPluginConfigPage, this, &KateMainWindow::showPluginConfigPage);
 
@@ -172,9 +174,10 @@ KateMainWindow::KateMainWindow(KConfig *sconfig, const QString &sgroup, bool use
 
     // prior to this there was (possibly) no view, therefore not context menu.
     // Hence, we have to take care of the menu bar here
+#if KATE_ALLOW_MENU_BAR_HIDE
     toggleShowMenuBar(false);
-
     ensureHamburgerBarSize();
+#endif
 
     // trigger proper focus restore
     m_viewManager->triggerActiveViewFocus();
@@ -234,9 +237,12 @@ QSize KateMainWindow::sizeHint() const
 
 void KateMainWindow::setupImportantActions()
 {
-    m_paShowStatusBar = KStandardAction::showStatusbar(this, SLOT(toggleShowStatusBar()), actionCollection());
+    m_paShowStatusBar = KStandardAction::showStatusbar(this, &KateMainWindow::toggleShowStatusBar, actionCollection());
     m_paShowStatusBar->setWhatsThis(i18n("Use this command to show or hide the view's statusbar"));
-    m_paShowMenuBar = KStandardAction::showMenubar(this, SLOT(toggleShowMenuBar()), actionCollection());
+
+#if KATE_ALLOW_MENU_BAR_HIDE
+    m_paShowMenuBar = KStandardAction::showMenubar(this, &KateMainWindow::toggleShowMenuBar, actionCollection());
+#endif
 
     m_paShowTabBar = new KToggleAction(i18n("Show &Tabs"), this);
     actionCollection()->addAction(QStringLiteral("settings_show_tab_bar"), m_paShowTabBar);
@@ -245,7 +251,9 @@ void KateMainWindow::setupImportantActions()
 
     m_paShowPath = new KToggleAction(i18n("Sho&w Path in Titlebar"), this);
     actionCollection()->addAction(QStringLiteral("settings_show_full_path"), m_paShowPath);
-    connect(m_paShowPath, SIGNAL(toggled(bool)), this, SLOT(updateCaption()));
+    connect(m_paShowPath, &QAction::toggled, this, [this] {
+        updateCaption(nullptr);
+    });
     m_paShowPath->setWhatsThis(i18n("Show the complete document path in the window caption"));
 
     m_paShowUrlNavBar = new KToggleAction(i18n("Show Navigation Bar"), this);
@@ -280,10 +288,16 @@ void KateMainWindow::setupImportantActions()
     connect(a, &QAction::triggered, this, &KateMainWindow::slotQuickOpen);
     a->setWhatsThis(i18n("Open a form to quick open documents."));
 
+#if KATE_ALLOW_MENU_BAR_HIDE
     // enable hamburger menu
     auto hamburgerMenu = static_cast<KHamburgerMenu *>(actionCollection()->addAction(KStandardAction::HamburgerMenu, QStringLiteral("hamburger_menu")));
     hamburgerMenu->setMenuBar(menuBar());
     hamburgerMenu->setShowMenuBarAction(m_paShowMenuBar);
+    if (KateApp::isKWrite()) {
+        hamburgerMenu->setMenuBarAdvertised(false);
+        connect(hamburgerMenu, &KHamburgerMenu::aboutToShowMenu, this, &KateMainWindow::updateHamburgerMenu);
+    }
+#endif
 }
 
 void KateMainWindow::setupMainWindow()
@@ -318,10 +332,10 @@ void KateMainWindow::setupActions()
     QAction *a;
 
     actionCollection()
-        ->addAction(KStandardAction::New, QStringLiteral("file_new"), m_viewManager, SLOT(slotDocumentNew()))
+        ->addAction(KStandardAction::New, QStringLiteral("file_new"), m_viewManager, &KateViewManager::slotDocumentNew)
         ->setWhatsThis(i18n("Create a new document"));
     actionCollection()
-        ->addAction(KStandardAction::Open, QStringLiteral("file_open"), m_viewManager, SLOT(slotDocumentOpen()))
+        ->addAction(KStandardAction::Open, QStringLiteral("file_open"), m_viewManager, &KateViewManager::slotDocumentOpen)
         ->setWhatsThis(i18n("Open an existing document for editing"));
 
     m_fileOpenRecent = KStandardAction::openRecent(
@@ -403,13 +417,15 @@ void KateMainWindow::setupActions()
     connect(a, &QAction::triggered, KateApp::self()->documentManager(), &KateDocManager::closeOrphaned);
     a->setWhatsThis(i18n("Close all documents in the file list that could not be reopened, because they are not accessible anymore."));
 
-    a = actionCollection()->addAction(KStandardAction::Close, QStringLiteral("file_close"), m_viewManager, SLOT(slotDocumentClose()));
+    a = actionCollection()->addAction(KStandardAction::Close, QStringLiteral("file_close"), m_viewManager, qOverload<>(&KateViewManager::slotDocumentClose));
     a->setIcon(QIcon::fromTheme(QStringLiteral("document-close")));
     a->setWhatsThis(i18n("Close the current document."));
 
     a = actionCollection()->addAction(QStringLiteral("file_close_other"));
     a->setText(i18n("Close Other"));
-    connect(a, SIGNAL(triggered()), this, SLOT(slotDocumentCloseOther()));
+    connect(a, &QAction::triggered, this, [this] {
+        slotDocumentCloseOther(nullptr);
+    });
     a->setWhatsThis(i18n("Close other open documents."));
 
     a = actionCollection()->addAction(QStringLiteral("file_close_all"));
@@ -417,6 +433,12 @@ void KateMainWindow::setupActions()
     connect(a, &QAction::triggered, this, &KateMainWindow::slotDocumentCloseAll);
     a->setWhatsThis(i18n("Close all open documents."));
 
+    a = actionCollection()->addAction(QStringLiteral("reopen_latest_closed_document"));
+    a->setText(i18n("&Reopen latest closed document(s)."));
+    // actionCollection()->setDefaultShortcut(a, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_T));
+    connect(a, &QAction::triggered, m_viewManager, &KateViewManager::slotRestoreLastClosedDocument);
+    a->setWhatsThis(i18n("Reopen the document or documents that were most recently closed"));
+
     a = actionCollection()->addAction(KStandardAction::Quit, QStringLiteral("file_quit"));
     // Qt::QueuedConnection: delay real shutdown, as we are inside menu action handling (bug #185708)
     connect(a, &QAction::triggered, this, &KateMainWindow::slotFileQuit, Qt::QueuedConnection);
@@ -443,13 +465,13 @@ void KateMainWindow::setupActions()
     // no open with for KWrite ATM
     documentOpenWith->setVisible(KateApp::isKate());
 
-    a = KStandardAction::keyBindings(this, SLOT(editKeys()), actionCollection());
+    a = KStandardAction::keyBindings(this, &KateMainWindow::editKeys, actionCollection());
     a->setWhatsThis(i18n("Configure the application's keyboard shortcut assignments."));
 
-    a = KStandardAction::configureToolbars(this, SLOT(slotEditToolbars()), actionCollection());
+    a = KStandardAction::configureToolbars(this, &KateMainWindow::slotEditToolbars, actionCollection());
     a->setWhatsThis(i18n("Configure which items should appear in the toolbar(s)."));
 
-    QAction *settingsConfigure = KStandardAction::preferences(this, SLOT(slotConfigure()), actionCollection());
+    QAction *settingsConfigure = KStandardAction::preferences(this, &KateMainWindow::slotConfigure, actionCollection());
     settingsConfigure->setWhatsThis(i18n("Configure various aspects of this application and the editing component."));
 
     if (KateApp::self()->pluginManager()->pluginList().size() > 0) {
@@ -558,32 +580,6 @@ void KateMainWindow::setupDiagnosticsView(KConfig *sconfig)
     m_diagView->actionCollection()->addAssociatedWidget(m_viewManager);
 }
 
-void KateMainWindow::ensureHamburgerBarSize()
-{
-    // Ensure the hamburger menu never gets pushed into the toolbar overflow
-    // by setting a minimum size on the bar based on the button's size.
-    if (auto *hamburgerBar = toolBar(QStringLiteral("hamburgerBar"))) {
-        auto *hamburgerMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
-        if (auto *hamburgerButton = hamburgerBar->widgetForAction(hamburgerMenu)) {
-            int neededButtonWidth = hamburgerButton->minimumSizeHint().width();
-            // Add toolbar margins.
-            const QMargins combinedMargins = hamburgerBar->contentsMargins() + hamburgerBar->layout()->contentsMargins();
-            neededButtonWidth += combinedMargins.left();
-            neededButtonWidth += combinedMargins.right();
-
-            // The dynamic spacer is also an action leading to spacing being added.
-            // Not observable with Breeze but e.g. Fusion style has toolbar button spacing.
-            if (hamburgerBar->actions().count() > 1) {
-                neededButtonWidth += hamburgerBar->layout()->spacing();
-            }
-
-            QSize minimumSize = hamburgerBar->minimumSize();
-            minimumSize.setWidth(std::max(minimumSize.width(), neededButtonWidth));
-            hamburgerBar->setMinimumSize(minimumSize);
-        }
-    }
-}
-
 void KateMainWindow::slotDocumentCloseAll()
 {
     if (!KateApp::self()->documentManager()->documentList().empty()
@@ -800,14 +796,18 @@ void KateMainWindow::readOptions()
 
     m_paShowPath->setChecked(generalGroup.readEntry("Show Full Path in Title", false));
     m_paShowStatusBar->setChecked(generalGroup.readEntry("Show Status Bar", true));
-    m_paShowMenuBar->setChecked(generalGroup.readEntry("Show Menu Bar", true));
     m_paShowTabBar->setChecked(generalGroup.readEntry("Show Tab Bar", true));
     m_paShowUrlNavBar->setChecked(generalGroup.readEntry("Show Url Nav Bar", KateApp::isKate()));
 
-    for (auto a : {m_paShowMenuBar, m_paShowTabBar, m_paShowPath, m_paShowUrlNavBar, m_paShowStatusBar}) {
+    for (auto a : {m_paShowTabBar, m_paShowPath, m_paShowUrlNavBar, m_paShowStatusBar}) {
         connect(a, &QAction::toggled, this, &KateMainWindow::saveOptions);
     }
 
+#if KATE_ALLOW_MENU_BAR_HIDE
+    m_paShowMenuBar->setChecked(generalGroup.readEntry("Show Menu Bar", KateApp::isKate()));
+    connect(m_paShowMenuBar, &QAction::toggled, this, &KateMainWindow::saveOptions);
+#endif
+
     m_mouseButtonBackAction = (MouseBackButtonAction)generalGroup.readEntry("Mouse back button action", 0);
     m_mouseButtonForwardAction = (MouseForwardButtonAction)generalGroup.readEntry("Mouse forward button action", 0);
 
@@ -829,11 +829,15 @@ void KateMainWindow::saveOptions()
 
     generalGroup.writeEntry("Show Full Path in Title", m_paShowPath->isChecked());
     generalGroup.writeEntry("Show Status Bar", m_paShowStatusBar->isChecked());
-    generalGroup.writeEntry("Show Menu Bar", m_paShowMenuBar->isChecked());
     generalGroup.writeEntry("Show Tab Bar", m_paShowTabBar->isChecked());
     generalGroup.writeEntry("Show Url Nav Bar", m_paShowUrlNavBar->isChecked());
+
+#if KATE_ALLOW_MENU_BAR_HIDE
+    generalGroup.writeEntry("Show Menu Bar", m_paShowMenuBar->isChecked());
+#endif
 }
 
+#if KATE_ALLOW_MENU_BAR_HIDE
 void KateMainWindow::toggleShowMenuBar(bool showMessage)
 {
     if (m_paShowMenuBar->isChecked()) {
@@ -844,7 +848,7 @@ void KateMainWindow::toggleShowMenuBar(bool showMessage)
     } else {
         // we have a hamburger button in the toolbar, we can avoid the message if that is still visible
         if (showMessage && toolBar()->isHidden()) {
-            const QString accel = m_paShowMenuBar->shortcut().toString();
+            const QString accel = m_paShowMenuBar->shortcut().toString(QKeySequence::NativeText);
             KMessageBox::information(this,
                                      i18n("This will hide the menu bar completely."
                                           " You can show it again by typing %1.",
@@ -859,6 +863,80 @@ void KateMainWindow::toggleShowMenuBar(bool showMessage)
     }
 }
 
+void KateMainWindow::ensureHamburgerBarSize()
+{
+    // Ensure the hamburger menu never gets pushed into the toolbar overflow
+    // by setting a minimum size on the bar based on the button's size.
+    if (auto *hamburgerBar = toolBar(QStringLiteral("hamburgerBar"))) {
+        auto *hamburgerMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
+        if (auto *hamburgerButton = hamburgerBar->widgetForAction(hamburgerMenu)) {
+            int neededButtonWidth = hamburgerButton->minimumSizeHint().width();
+            // Add toolbar margins.
+            const QMargins combinedMargins = hamburgerBar->contentsMargins() + hamburgerBar->layout()->contentsMargins();
+            neededButtonWidth += combinedMargins.left();
+            neededButtonWidth += combinedMargins.right();
+
+            // The dynamic spacer is also an action leading to spacing being added.
+            // Not observable with Breeze but e.g. Fusion style has toolbar button spacing.
+            if (hamburgerBar->actions().count() > 1) {
+                neededButtonWidth += hamburgerBar->layout()->spacing();
+            }
+
+            QSize minimumSize = hamburgerBar->minimumSize();
+            minimumSize.setWidth(std::max(minimumSize.width(), neededButtonWidth));
+            hamburgerBar->setMinimumSize(minimumSize);
+        }
+    }
+}
+
+void KateMainWindow::updateHamburgerMenu()
+{
+    auto *hamburgerMenu = actionCollection()->action(QStringLiteral("hamburger_menu"));
+    auto menu = hamburgerMenu->menu();
+
+    if (!menu) {
+        menu = new QMenu(this);
+        hamburgerMenu->setMenu(menu);
+    } else {
+        menu->clear();
+    }
+
+    menu->addAction(actionCollection()->action(QStringLiteral("file_new")));
+    menu->addAction(actionCollection()->action(QStringLiteral("file_open")));
+    menu->addSeparator();
+
+    if (auto view = viewManager()->activeView()) {
+        menu->addAction(view->actionCollection()->action(QStringLiteral("file_save")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("file_save_as")));
+        menu->addSeparator();
+
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_undo")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_redo")));
+        menu->addSeparator();
+
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_cut")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_copy")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_paste")));
+        menu->addSeparator();
+
+        menu->addAction(view->actionCollection()->action(QStringLiteral("file_print")));
+        menu->addSeparator();
+
+        menu->addAction(view->actionCollection()->action(QStringLiteral("edit_find")));
+        menu->addSeparator();
+
+        menu->addAction(view->actionCollection()->action(QStringLiteral("view_inc_font_sizes")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("view_dec_font_sizes")));
+        menu->addAction(view->actionCollection()->action(QStringLiteral("view_reset_font_sizes")));
+        menu->addSeparator();
+    }
+
+    for (QAction *menuAction : menuBar()->actions()) {
+        menu->addAction(menuAction);
+    }
+}
+#endif
+
 void KateMainWindow::toggleShowStatusBar()
 {
     // just hide or show the status bar stack
@@ -942,7 +1020,7 @@ void KateMainWindow::slotDropEvent(QDropEvent *event)
             }
         }
 
-        for (const QUrl &url : qAsConst(textlist)) {
+        for (const QUrl &url : std::as_const(textlist)) {
             // if url has no file component, try and recursively scan dir
             KFileItem kitem(url);
             kitem.setDelayedMimeTypes(true);
@@ -1391,7 +1469,7 @@ bool KateMainWindow::addWidget(QWidget *widget)
 
     auto vs = m_viewManager->activeViewSpace();
     vs->addWidgetAsTab(widget);
-    Q_EMIT widgetAdded(widget);
+    Q_EMIT wrapper()->widgetAdded(widget);
     m_viewManager->activateView(widget);
     return true;
 }
