@@ -18,6 +18,7 @@
 
 #include <QAbstractListModel>
 #include <QApplication>
+#include <QClipboard>
 #include <QDir>
 #include <QHBoxLayout>
 #include <QIcon>
@@ -44,7 +45,6 @@ using namespace std::chrono_literals;
 
 class FuzzyFilterModel final : public QSortFilterProxyModel
 {
-    Q_OBJECT
 public:
     explicit FuzzyFilterModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
@@ -204,7 +204,6 @@ using FilterableTreeView = FilterableItemView<QTreeView>;
 
 class DirFilesModel : public QAbstractListModel
 {
-    Q_OBJECT
 public:
     DirFilesModel(QObject *parent = nullptr)
         : QAbstractListModel(parent)
@@ -515,7 +514,6 @@ enum BreadCrumbRole {
 
 class BreadCrumbDelegate : public QStyledItemDelegate
 {
-    Q_OBJECT
 public:
     using QStyledItemDelegate::QStyledItemDelegate;
 
@@ -587,6 +585,9 @@ public:
         connect(KTextEditor::Editor::instance(), &KTextEditor::Editor::configChanged, this, &BreadCrumbView::updatePalette, Qt::QueuedConnection);
         updatePalette();
 
+        setContextMenuPolicy(Qt::CustomContextMenu);
+        connect(this, &BreadCrumbView::customContextMenuRequested, this, &BreadCrumbView::onContextMenu);
+
         auto onConfigChanged = [this] {
             KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("General"));
             auto v = cg.readEntry("Show Symbol In Navigation Bar", true);
@@ -625,14 +626,14 @@ public:
         m_symbolsModel = nullptr;
 
         size_t i = 0;
-        QIcon seperator = m_urlBar->seperator();
+        QIcon separator = m_urlBar->separator();
         for (const auto &dir : dirs) {
             auto item = new QStandardItem(dir.name);
             item->setData(dir.path, BreadCrumbRole::PathRole);
             m_model.appendRow(item);
 
             if (i < dirs.size() - 1) {
-                auto sep = new QStandardItem(seperator, {});
+                auto sep = new QStandardItem(separator, {});
                 sep->setSelectable(false);
                 sep->setData(true, BreadCrumbRole::IsSeparator);
                 m_model.appendRow(sep);
@@ -677,13 +678,13 @@ public:
         }
         std::reverse(dirs.begin(), dirs.end());
 
-        QIcon seperator = m_urlBar->seperator();
+        QIcon separator = m_urlBar->separator();
         for (const auto &dir : dirs) {
             auto item = new QStandardItem(dir.name);
             item->setData(dir.path, BreadCrumbRole::PathRole);
             m_model.appendRow(item);
 
-            auto sep = new QStandardItem(seperator, {});
+            auto sep = new QStandardItem(separator, {});
             sep->setSelectable(false);
             sep->setData(true, BreadCrumbRole::IsSeparator);
             m_model.appendRow(sep);
@@ -717,7 +718,7 @@ public:
         }
 
         // Add separator
-        auto sep = new QStandardItem(QIcon(m_urlBar->seperator()), {});
+        auto sep = new QStandardItem(QIcon(m_urlBar->separator()), {});
         sep->setSelectable(false);
         sep->setData(true, BreadCrumbRole::IsSeparator);
         m_model.appendRow(sep);
@@ -753,7 +754,7 @@ public:
 
         if (!item || !item->data(BreadCrumbRole::IsSymbolCrumb).toBool()) {
             // Add separator
-            auto sep = new QStandardItem(QIcon(m_urlBar->seperator()), {});
+            auto sep = new QStandardItem(QIcon(m_urlBar->separator()), {});
             sep->setSelectable(false);
             sep->setData(true, BreadCrumbRole::IsSeparator);
             m_model.appendRow(sep);
@@ -867,6 +868,28 @@ public:
         m_isNavigating = false;
     }
 
+    void onContextMenu(const QPoint &pos)
+    {
+        if (selectedIndexes().empty()) {
+            return;
+        }
+        QMenu menu = QMenu(viewport());
+        QModelIndex selectedIndex = selectedIndexes().constFirst();
+        bool last = selectedIndex == m_model.index(m_model.rowCount() - 1, 0);
+        auto path = selectedIndex.data(BreadCrumbRole::PathRole).toString();
+        if (!path.isEmpty()) {
+            menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy-path")), i18nc("@menu:action", "Copy Location"), this, [path] {
+                QGuiApplication::clipboard()->setText(path);
+            });
+        }
+        if (last) {
+            menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18nc("@menu:action", "Copy Filename"), this, [selectedIndex] {
+                QGuiApplication::clipboard()->setText(selectedIndex.data().toString());
+            });
+        }
+        menu.exec(mapToGlobal(pos));
+    }
+
     bool navigating() const
     {
         return m_isNavigating;
@@ -881,13 +904,13 @@ public:
         }
     }
 
-    void updateSeperatorIcon()
+    void updateSeparatorIcon()
     {
-        auto newSeperator = m_urlBar->seperator();
+        auto newSeparator = m_urlBar->separator();
         for (int i = 0; i < m_model.rowCount(); ++i) {
             auto item = m_model.item(i);
             if (item && item->data(BreadCrumbRole::IsSeparator).toBool()) {
-                item->setIcon(newSeperator);
+                item->setIcon(newSeparator);
             }
         }
     }
@@ -981,7 +1004,6 @@ Q_SIGNALS:
 // TODO: Merge this class back into KateUrlBar
 class UrlbarContainer : public QWidget
 {
-    Q_OBJECT
 public:
     UrlbarContainer(KateUrlBar *parent)
         : QWidget(parent)
@@ -1037,7 +1059,7 @@ public:
             [this] {
                 m_sepPixmap = QPixmap();
                 initSeparatorIcon();
-                m_mainCrumbView->updateSeperatorIcon();
+                m_mainCrumbView->updateSeparatorIcon();
             },
             Qt::QueuedConnection);
 
@@ -1176,7 +1198,7 @@ KateViewSpace *KateUrlBar::viewSpace()
     return m_parentViewSpace;
 }
 
-QIcon KateUrlBar::seperator()
+QIcon KateUrlBar::separator()
 {
     return m_urlBarView->separatorPixmap();
 }
