@@ -29,10 +29,6 @@
 #include <KToolBar>
 #include <KXMLGUIFactory>
 
-#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
-#include <KActivities/ResourceInstance>
-#endif
-
 #include <QFileDialog>
 #include <QTimer>
 
@@ -49,6 +45,10 @@ KateViewManager::KateViewManager(QWidget *parentW, KateMainWindow *parent)
 {
     setObjectName(QStringLiteral("KateViewManager"));
 
+    // start in home if we are not started from a terminal
+    m_lastOpenDialogUrl =
+        QUrl::fromLocalFile(KateApp::isInsideTerminal() ? QDir::currentPath() : QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+
     // we don't allow full collapse, see bug 366014
     setChildrenCollapsible(false);
 
@@ -100,10 +100,26 @@ KateViewManager::~KateViewManager()
 void KateViewManager::readConfig()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup cgGeneral = KConfigGroup(config, "General");
+    KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
     m_sdiMode = cgGeneral.readEntry("SDI Mode", false);
 }
 
+void KateViewManager::slotScrollSynchedViews(KTextEditor::View *view)
+{
+    //  Match current view
+    QHash<KTextEditor::View *, ScrollSynchronisation::ScrollBarInfo>::const_iterator currentViewInfo = m_scrollSynchronisation.viewScrollInfo.constFind(view);
+    //  Delta scroll in reference scroll value
+    m_scrollSynchronisation.referenceScrollValue = currentViewInfo.value().scrollBar->value() - currentViewInfo.value().initScrollValue;
+    //  Delta scroll in all other views
+    for (auto otherViewInfo = m_scrollSynchronisation.viewScrollInfo.constBegin(), end = m_scrollSynchronisation.viewScrollInfo.constEnd();
+         otherViewInfo != end;
+         ++otherViewInfo) {
+        if (otherViewInfo != currentViewInfo) {
+            otherViewInfo.value().scrollBar->setValue(m_scrollSynchronisation.referenceScrollValue + otherViewInfo.value().initScrollValue);
+        }
+    }
+}
+
 void KateViewManager::setupActions()
 {
     /**
@@ -315,7 +331,7 @@ void KateViewManager::slotDocumentOpen()
      * emit size warning, for local files
      */
     QString fileListWithTooLargeFiles;
-    for (const QUrl &url : qAsConst(urls)) {
+    for (const QUrl &url : std::as_const(urls)) {
         if (!url.isLocalFile()) {
             continue;
         }
@@ -330,20 +346,8 @@ void KateViewManager::slotDocumentOpen()
             "<p>You are attempting to open one or more large files:</p><ul>%1</ul><p>Do you want to proceed?</p><p><strong>Beware that kate may stop "
             "responding for some time when opening large files.</strong></p>",
             fileListWithTooLargeFiles);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-        const auto ret = KMessageBox::warningTwoActions(this,
-#else
-        const auto ret = KMessageBox::warningYesNo(this,
-#endif
-                                                        text,
-                                                        i18n("Opening Large File"),
-                                                        KStandardGuiItem::cont(),
-                                                        KStandardGuiItem::stop());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const auto ret = KMessageBox::warningTwoActions(this, text, i18n("Opening Large File"), KStandardGuiItem::cont(), KStandardGuiItem::stop());
         if (ret == KMessageBox::SecondaryAction) {
-#else
-        if (ret == KMessageBox::No) {
-#endif
             return;
         }
     }
@@ -352,7 +356,7 @@ void KateViewManager::slotDocumentOpen()
     KateDocumentInfo docInfo;
     docInfo.openedByUser = true;
     if (KTextEditor::Document *lastID = openUrls(urls, QString(), docInfo)) {
-        for (const QUrl &url : qAsConst(urls)) {
+        for (const QUrl &url : std::as_const(urls)) {
             m_mainWindow->addRecentOpenedFile(url);
         }
         activateView(lastID);
@@ -369,7 +373,7 @@ void KateViewManager::slotDocumentClose(KTextEditor::Document *document)
         }
 
         KSharedConfig::Ptr config = KSharedConfig::openConfig();
-        KConfigGroup cgGeneral = KConfigGroup(config, "General");
+        KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
 
         // Otherwise, show the welcome view
         if (cgGeneral.readEntry("Show welcome view for new window", true)) {
@@ -396,6 +400,16 @@ void KateViewManager::slotDocumentClose()
     }
 }
 
+void KateViewManager::slotRestoreLastClosedDocument()
+{
+    const auto &documentManager = KateApp::self()->documentManager();
+    if (const auto recentlyClosedUrls = documentManager->popRecentlyClosedUrls(); !recentlyClosedUrls.isEmpty()) {
+        if (const auto restoredDoc = openUrls(recentlyClosedUrls, QString())) {
+            activateView(restoredDoc);
+        }
+    }
+}
+
 KTextEditor::Document *
 KateViewManager::openUrl(const QUrl &url, const QString &encoding, bool activate, bool ignoreForRecentFiles, const KateDocumentInfo &docInfo)
 {
@@ -436,8 +450,9 @@ KTextEditor::Document *KateViewManager::openUrls(const QList<QUrl> &urls, const
     bool first = true;
     KTextEditor::Document *lastDocInThisViewManager = nullptr;
     for (auto doc : docs) {
-        // it we have a doc to close, we can use this window for the first document even in SDI mode
-        if (!m_sdiMode || (first && docToClose) || m_views.empty()) {
+        // it we have a document to close, we can use this window for the first document even in SDI mode
+        // try to re-use open views to avoid massive windows spawning, see bug 474775
+        if (!m_sdiMode || (first && docToClose) || m_views.empty() || activeViewSpace()->hasDocument(doc)) {
             // forward to currently active view space
             activeViewSpace()->registerDocument(doc);
             connect(doc, &KTextEditor::Document::documentSavedOrUploaded, this, &KateViewManager::documentSavedOrUploaded);
@@ -520,21 +535,12 @@ void KateViewManager::openUrlOrProject(const QUrl &url)
 
         KatePluginInfo &projectPluginInfo = *i;
         text = i18n("In order to open folders, the <b>%1</b> plugin must be enabled. Enable it?", projectPluginInfo.metaData.name());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
-        if (KMessageBox::questionTwoActions(
-#else
-        if (KMessageBox::questionYesNo(
-#endif
-                mainWindow(),
-                text,
-                i18nc("@title:window", "Open Folder"),
-                KGuiItem(i18nc("@action:button", "Enable"), QStringLiteral("dialog-ok")),
-                KStandardGuiItem::cancel())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::questionTwoActions(mainWindow(),
+                                            text,
+                                            i18nc("@title:window", "Open Folder"),
+                                            KGuiItem(i18nc("@action:button", "Enable"), QStringLiteral("dialog-ok")),
+                                            KStandardGuiItem::cancel())
             == KMessageBox::SecondaryAction) {
-#else
-            == KMessageBox::No) {
-#endif
             return;
         }
 
@@ -655,15 +661,9 @@ KTextEditor::View *KateViewManager::createView(KTextEditor::Document *doc, KateV
 
     /**
      * remember this view, active == false, min age set
-     * create activity resource
      */
     m_views[view].lruAge = m_minAge--;
 
-#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
-    m_views[view].activityResource = new KActivities::ResourceInstance(view->window()->winId(), view);
-    m_views[view].activityResource->setUri(doc->url());
-#endif
-
     // disable settings dialog action
     delete view->actionCollection()->action(QStringLiteral("set_confdlg"));
 
@@ -713,7 +713,7 @@ bool KateViewManager::deleteView(KTextEditor::View *view)
         return true;
     }
 
-    KateViewSpace *viewspace = static_cast<KateViewSpace *>(view->parentWidget()->parentWidget());
+    KateViewSpace *viewspace = static_cast<KateViewSpace *>(view->parent()->parent());
     viewspace->removeView(view);
     updateViewSpaceActions();
 
@@ -802,7 +802,7 @@ void KateViewManager::activateSpace(KTextEditor::View *v)
         return;
     }
 
-    KateViewSpace *vs = static_cast<KateViewSpace *>(v->parentWidget()->parentWidget());
+    KateViewSpace *vs = static_cast<KateViewSpace *>(v->parent()->parent());
 
     if (!vs->isActiveSpace()) {
         setActiveSpace(vs);
@@ -868,12 +868,6 @@ void KateViewManager::activateView(KTextEditor::View *view)
         Q_EMIT viewChanged(view);
 
         updateViewSpaceActions();
-
-#if defined(KF5Activities_FOUND) || defined(KF6Activities_FOUND)
-        // inform activity manager
-        m_views[view].activityResource->setUri(view->document()->url());
-        m_views[view].activityResource->notifyFocusedIn();
-#endif
     }
 }
 
@@ -961,7 +955,7 @@ void KateViewManager::activateIntuitiveNeighborView(Qt::Orientation o, int dir)
     if (!currentViewSpace) {
         return;
     }
-    KateViewSpace *target = findIntuitiveNeighborView(qobject_cast<KateSplitter *>(currentViewSpace->parentWidget()), currentViewSpace, o, dir);
+    KateViewSpace *target = findIntuitiveNeighborView(qobject_cast<KateSplitter *>(currentViewSpace->parent()), currentViewSpace, o, dir);
     if (target) {
         setActiveSpace(target);
         activateView(target->currentView());
@@ -999,8 +993,8 @@ KateViewSpace *KateViewManager::findIntuitiveNeighborView(KateSplitter *splitter
             } else { // otherwise we need to find in which of the two child to go based on the cursor position
                 QPoint cursorCoord = activeView()->mapToGlobal(activeView()->cursorPositionCoordinates());
                 QPoint targetSplitterCoord = targetSplitter->widget(0)->mapToGlobal(QPoint(0, 0));
-                if ((o == Qt::Horizontal && (targetSplitterCoord.y() + targetSplitter->sizes()[0] > cursorCoord.y()))
-                    || (o == Qt::Vertical && (targetSplitterCoord.x() + targetSplitter->sizes()[0] > cursorCoord.x()))) {
+                if ((o == Qt::Horizontal && (targetSplitterCoord.y() + targetSplitter->sizes().constFirst() > cursorCoord.y()))
+                    || (o == Qt::Vertical && (targetSplitterCoord.x() + targetSplitter->sizes().constFirst() > cursorCoord.x()))) {
                     targetChild = targetSplitter->widget(0);
                 } else {
                     targetChild = targetSplitter->widget(1);
@@ -1016,7 +1010,7 @@ KateViewSpace *KateViewManager::findIntuitiveNeighborView(KateSplitter *splitter
         }
     }
     // otherwise try to go up in the splitter tree
-    return findIntuitiveNeighborView(qobject_cast<KateSplitter *>(splitter->parentWidget()), splitter, o, dir);
+    return findIntuitiveNeighborView(qobject_cast<KateSplitter *>(splitter->parent()), splitter, o, dir);
 }
 
 void KateViewManager::documentWillBeDeleted(KTextEditor::Document *doc)
@@ -1040,13 +1034,13 @@ void KateViewManager::documentWillBeDeleted(KTextEditor::Document *doc)
 void KateViewManager::closeView(KTextEditor::View *view)
 {
     // we can only close views that are in our viewspaces
-    if (!view || !view->parentWidget() || !view->parentWidget()->parentWidget()) {
+    if (!view || !view->parent() || !view->parent()->parent()) {
         return;
     }
 
     // get the viewspace if possible and close the document there => should close the passed view
     // will close the full document, too, if last
-    auto viewSpace = qobject_cast<KateViewSpace *>(view->parentWidget()->parentWidget());
+    auto viewSpace = qobject_cast<KateViewSpace *>(view->parent()->parent());
     if (viewSpace) {
         viewSpace->closeDocument(view->document());
     }
@@ -1101,7 +1095,7 @@ void KateViewManager::splitViewSpace(KateViewSpace *vs, // = 0
     }
 
     // get current splitter, and abort if null
-    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parentWidget());
+    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parent());
     if (!currentSplitter) {
         return;
     }
@@ -1168,12 +1162,99 @@ void KateViewManager::splitViewSpace(KateViewSpace *vs, // = 0
     updateViewSpaceActions();
 }
 
+void KateViewManager::slotSynchroniseScrolling(bool checked)
+{
+    KTextEditor::View *userSelectedView = activeViewSpace()->currentView();
+    auto newSynchedViewInfo = m_scrollSynchronisation.viewScrollInfo.constFind(userSelectedView);
+    // If already added to sync, then desync
+    if (newSynchedViewInfo != m_scrollSynchronisation.viewScrollInfo.constEnd()) {
+        Q_ASSERT(!checked);
+        disconnect(userSelectedView, &KTextEditor::View::verticalScrollPositionChanged, this, &KateViewManager::slotScrollSynchedViews);
+        m_scrollSynchronisation.viewScrollInfo.remove(newSynchedViewInfo.key());
+        m_scrollSynchronisation.synchedViewSpaces.remove(activeViewSpace());
+        if (m_scrollSynchronisation.synchedViewSpaces.isEmpty()) {
+            disconnect(this, &KateViewManager::viewChanged, this, &KateViewManager::slotChangeSynchedView);
+        }
+        return;
+    }
+    // If invalid, do nothing
+    if (!userSelectedView) {
+        activeViewSpace()->setToggleSynchronisedScrollingCheckedState(false);
+        return;
+    }
+    // If not already added to sync, then add to sync
+    Q_ASSERT(checked);
+    ScrollSynchronisation::ScrollBarInfo scrollBarInfo = m_scrollSynchronisation.getViewScrollBarInfo(userSelectedView);
+    if (!scrollBarInfo.scrollBar) {
+        // This case should normally not occur
+        // but if it is being used, implement:
+        // Uncheck m_toggleSynchronisedScrolling
+        return;
+    }
+    // Connect scrolling to slotSynchedView
+    connect(userSelectedView, &KTextEditor::View::verticalScrollPositionChanged, this, &KateViewManager::slotScrollSynchedViews, Qt::UniqueConnection);
+    m_scrollSynchronisation.viewScrollInfo.insert(userSelectedView, scrollBarInfo);
+    // Remove from group of views, when view is deleted
+    connect(userSelectedView, &KTextEditor::View::destroyed, this, [this](QObject *obj) {
+        m_scrollSynchronisation.viewScrollInfo.remove(static_cast<KTextEditor::View *>(obj));
+    });
+    // To cater for multiple views per viewspace
+    Q_ASSERT_X(!m_scrollSynchronisation.synchedViewSpaces.contains(activeViewSpace()),
+               "void KateViewManager::slotSynchroniseScrolling()",
+               "Somehow m_synchedViewSpaces already contains the viewspace currently selected");
+    m_scrollSynchronisation.synchedViewSpaces.insert(activeViewSpace(), activeViewSpace()->currentView());
+    // Change stored view whenever user changes tab
+    connect(this, &KateViewManager::viewChanged, this, &KateViewManager::slotChangeSynchedView, Qt::UniqueConnection);
+    // Remove from group of viewSpaces when the viewSpace is deleted
+    connect(
+        activeViewSpace(),
+        &KateViewSpace::destroyed,
+        this,
+        [this](QObject *obj) {
+            if (m_scrollSynchronisation.synchedViewSpaces.contains(static_cast<KateViewSpace *>(obj))) {
+                m_scrollSynchronisation.synchedViewSpaces.remove(static_cast<KateViewSpace *>(obj));
+            }
+        },
+        Qt::QueuedConnection);
+}
+
+void KateViewManager::slotChangeSynchedView(KTextEditor::View *currentView)
+{
+    if (m_scrollSynchronisation.synchedViewSpaces.constFind(activeViewSpace()) == m_scrollSynchronisation.synchedViewSpaces.constEnd()) {
+        // If currently selected view is not a part of scroll-synched viewspace do nothing
+        return;
+    }
+    // Remove previous view from scroll-sync
+    KTextEditor::View *previousView = m_scrollSynchronisation.synchedViewSpaces.constFind(activeViewSpace()).value();
+    if (previousView == currentView) {
+        // If this function has been called just because the activeViewSpace was changed then don't
+        // waste time
+        return;
+    }
+    disconnect(previousView, &KTextEditor::View::verticalScrollPositionChanged, this, &KateViewManager::slotScrollSynchedViews);
+    m_scrollSynchronisation.viewScrollInfo.remove(previousView);
+    // Add the currentView to scroll-sync
+    ScrollSynchronisation::ScrollBarInfo scrollBarInfo = m_scrollSynchronisation.getViewScrollBarInfo(currentView);
+    if (!scrollBarInfo.scrollBar) {
+        return;
+    }
+    // Connect scrolling to slotSynchedView
+    connect(currentView, &KTextEditor::View::verticalScrollPositionChanged, this, &KateViewManager::slotScrollSynchedViews, Qt::UniqueConnection);
+    m_scrollSynchronisation.viewScrollInfo.insert(currentView, scrollBarInfo);
+    // Remove from group of views, when view is deleted
+    connect(currentView, &KTextEditor::View::destroyed, this, [this](QObject *obj) {
+        m_scrollSynchronisation.viewScrollInfo.remove(static_cast<KTextEditor::View *>(obj));
+    });
+    // Add the new view alongside the viewspace already in list
+    m_scrollSynchronisation.synchedViewSpaces[activeViewSpace()] = currentView;
+}
+
 void KateViewManager::closeViewSpace(KTextEditor::View *view)
 {
     KateViewSpace *space;
 
     if (view) {
-        space = static_cast<KateViewSpace *>(view->parentWidget()->parentWidget());
+        space = static_cast<KateViewSpace *>(view->parent()->parent());
     } else {
         space = activeViewSpace();
     }
@@ -1188,7 +1269,7 @@ void KateViewManager::toggleSplitterOrientation()
     }
 
     // get current splitter, and abort if null
-    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parentWidget());
+    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parent());
     if (!currentSplitter || (currentSplitter->count() == 1)) {
         return;
     }
@@ -1258,8 +1339,8 @@ bool KateViewManager::viewsInSameViewSpace(KTextEditor::View *view1, KTextEditor
         return true;
     }
 
-    KateViewSpace *vs1 = static_cast<KateViewSpace *>(view1->parentWidget()->parentWidget());
-    KateViewSpace *vs2 = static_cast<KateViewSpace *>(view2->parentWidget()->parentWidget());
+    KateViewSpace *vs1 = static_cast<KateViewSpace *>(view1->parent()->parent());
+    KateViewSpace *vs2 = static_cast<KateViewSpace *>(view2->parent()->parent());
     return vs1 && (vs1 == vs2);
 }
 
@@ -1295,7 +1376,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
     }
 
     // get current splitter
-    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(viewspace->parentWidget());
+    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(viewspace->parent());
 
     // no splitter found, bah
     if (!currentSplitter) {
@@ -1323,7 +1404,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
         // emit widget removed
         const auto widgets = viewspace->widgets();
         for (auto w : widgets) {
-            Q_EMIT mainWindow()->widgetRemoved(w);
+            Q_EMIT mainWindow()->wrapper()->widgetRemoved(w);
         }
     }
 
@@ -1338,7 +1419,7 @@ void KateViewManager::removeViewSpace(KateViewSpace *viewspace)
     // the splitter then.
     if (currentSplitter != this) {
         // get parent splitter
-        KateSplitter *parentSplitter = qobject_cast<KateSplitter *>(currentSplitter->parentWidget());
+        KateSplitter *parentSplitter = qobject_cast<KateSplitter *>(currentSplitter->parent());
 
         // only do magic if found ;)
         if (parentSplitter) {
@@ -1612,7 +1693,7 @@ void KateViewManager::moveSplitter(Qt::Key key, int repeats)
         return;
     }
 
-    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parentWidget());
+    KateSplitter *currentSplitter = qobject_cast<KateSplitter *>(vs->parent());
 
     if (!currentSplitter) {
         return;
@@ -1624,11 +1705,7 @@ void KateViewManager::moveSplitter(Qt::Key key, int repeats)
     int move = 4 * repeats;
     // try to use font height in pixel to move splitter
     {
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-        KTextEditor::Attribute::Ptr attrib(vs->currentView()->defaultStyleAttribute(KTextEditor::dsNormal));
-#else
         KTextEditor::Attribute::Ptr attrib(vs->currentView()->defaultStyleAttribute(KSyntaxHighlighting::Theme::TextStyle::Normal));
-#endif
         QFontMetrics fm(attrib->font());
         move = fm.height() * repeats;
     }
@@ -1681,7 +1758,7 @@ void KateViewManager::moveSplitter(Qt::Key key, int repeats)
 
         currentWidget = static_cast<QWidget *>(currentSplitter);
         // the parent of the current splitter will become the current splitter
-        currentSplitter = qobject_cast<KateSplitter *>(currentSplitter->parentWidget());
+        currentSplitter = qobject_cast<KateSplitter *>(currentSplitter->parent());
     }
 }
 
@@ -1705,7 +1782,7 @@ void KateViewManager::showWelcomeViewOrNewDocumentIfNeeded()
 
         // the user can decide: welcome page or a new untitled document for a new window?
         KSharedConfig::Ptr config = KSharedConfig::openConfig();
-        KConfigGroup cgGeneral = KConfigGroup(config, "General");
+        KConfigGroup cgGeneral = KConfigGroup(config, QStringLiteral("General"));
         if (!m_welcomeViewAlreadyShown && cgGeneral.readEntry("Show welcome view for new window", true)) {
             showWelcomeView();
         } else {
