@@ -81,7 +81,9 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     connect(m_tabBar, &KateTabBar::tabCloseRequested, this, &KateViewSpace::closeTabRequest, Qt::QueuedConnection);
     connect(m_tabBar, &KateTabBar::contextMenuRequest, this, &KateViewSpace::showContextMenu, Qt::QueuedConnection);
     connect(m_tabBar, &KateTabBar::newTabRequested, this, &KateViewSpace::createNewDocument);
-    connect(m_tabBar, SIGNAL(activateViewSpaceRequested()), this, SLOT(makeActive()));
+    connect(m_tabBar, &KateTabBar::activateViewSpaceRequested, this, [this] {
+        makeActive(true);
+    });
     hLayout->addWidget(m_tabBar);
 
     // add quick open
@@ -182,8 +184,8 @@ KateViewSpace::KateViewSpace(KateViewManager *viewManager, QWidget *parent, cons
     // ensure we show/hide tabbar if needed
     connect(m_viewManager, &KateViewManager::viewCreated, this, &KateViewSpace::updateTabBar);
     connect(KateApp::self()->documentManager(), &KateDocManager::documentsDeleted, this, &KateViewSpace::updateTabBar);
-    connect(m_viewManager->mainWindow(), &KateMainWindow::widgetAdded, this, &KateViewSpace::updateTabBar);
-    connect(m_viewManager->mainWindow(), &KateMainWindow::widgetRemoved, this, &KateViewSpace::updateTabBar);
+    connect(m_viewManager->mainWindow()->wrapper(), &KTextEditor::MainWindow::widgetAdded, this, &KateViewSpace::updateTabBar);
+    connect(m_viewManager->mainWindow()->wrapper(), &KTextEditor::MainWindow::widgetRemoved, this, &KateViewSpace::updateTabBar);
 }
 
 KateViewSpace::~KateViewSpace() = default;
@@ -208,7 +210,7 @@ bool KateViewSpace::eventFilter(QObject *obj, QEvent *event)
         QHelpEvent *e = static_cast<QHelpEvent *>(event);
         QAction *quickOpen = m_viewManager->mainWindow()->actionCollection()->action(QStringLiteral("view_quick_open"));
         Q_ASSERT(quickOpen);
-        QToolTip::showText(e->globalPos(), button->toolTip() + QStringLiteral(" (%1)").arg(quickOpen->shortcut().toString()), button);
+        QToolTip::showText(e->globalPos(), button->toolTip() + QStringLiteral(" (%1)").arg(quickOpen->shortcut().toString(QKeySequence::NativeText)), button);
         return true;
     }
 
@@ -286,7 +288,7 @@ void KateViewSpace::tabBarToggled()
 
 void KateViewSpace::urlBarToggled(bool show)
 {
-    const bool tabBarVisible = m_viewManager->mainWindow()->showTabBar();
+    const bool tabBarVisible = m_tabBar->isVisible();
     bool showButtons = true;
     if (!show && !tabBarVisible) {
         // Tab bar was already hidden, now url bar is also hidden
@@ -805,7 +807,7 @@ void KateViewSpace::removeWidget(QWidget *w)
         m_tabBar->blockSignals(false);
 
         w->deleteLater();
-        Q_EMIT m_viewManager->mainWindow()->widgetRemoved(w);
+        Q_EMIT m_viewManager->mainWindow()->wrapper()->widgetRemoved(w);
 
         // If some tab was removed, switch to most recently used doc
         if (idx >= 0) {
@@ -926,6 +928,11 @@ void KateViewSpace::focusNavigationBar()
     }
 }
 
+void KateViewSpace::setToggleSynchronisedScrollingCheckedState(bool checked)
+{
+    m_toggleSynchronisedScrolling->setChecked(checked);
+}
+
 void KateViewSpace::addPositionToHistory(const QUrl &url, KTextEditor::Cursor c, bool calledExternally)
 {
     // We don't care about invalid urls (Fixed Diff View / Untitled docs)
@@ -1120,7 +1127,10 @@ void KateViewSpace::showContextMenu(int idx, const QPoint &globalPos)
     } else if (choice == aRenameFile) {
         KateFileActions::renameDocumentFile(this, doc);
     } else if (choice == aDeleteFile) {
-        KateFileActions::deleteDocumentFile(this, doc);
+        // use single shot as this action can trigger deletion of this viewspace!
+        QTimer::singleShot(0, this, [this, doc]() {
+            KateFileActions::deleteDocumentFile(this, doc);
+        });
     } else if (choice->parent() == compareUsing) {
         QString actionData = choice->data().toString(); // name of the executable of the diff program
         if (!KateFileActions::compareWithExternalProgram(activeDocument, doc, actionData)) {
