@@ -33,6 +33,23 @@
 #include <unistd.h>
 #endif
 
+namespace
+{
+QStringList getAllSessionsInDir(const QString &dirPath)
+{
+    // Let's get a list of all session we have atm
+    QDir dir(dirPath, QStringLiteral("*.katesession"), QDir::Time);
+    QStringList sessionList;
+    sessionList.reserve(dir.count());
+    for (unsigned int i = 0; i < dir.count(); ++i) {
+        QString name = dir[i];
+        name.chop(12); // .katesession
+        sessionList << QUrl::fromPercentEncoding(name.toLatin1());
+    }
+    return sessionList;
+}
+}
+
 // BEGIN KateSessionManager
 
 KateSessionManager::KateSessionManager(QObject *parent, const QString &sessionsDir)
@@ -63,33 +80,23 @@ KateSessionManager::KateSessionManager(QObject *parent, const QString &sessionsD
     connect(dm, &KateDocManager::documentDeleted, &m_sessionSaveTimer, startTimer);
     m_sessionSaveTimer.callOnTimeout(this, [this] {
         if (m_sessionSaveTimerBlocked == 0) {
-            saveActiveSession(true);
+            saveActiveSession(true, /*isAutoSave=*/true);
         }
     });
 }
 
-KateSessionManager::~KateSessionManager() = default;
+KateSessionManager::~KateSessionManager()
+{
+    // write jump list actions to disk in the kate.desktop file
+    updateJumpListActions();
+}
 
 void KateSessionManager::updateSessionList()
 {
-    QStringList list;
-
-    // Let's get a list of all session we have atm
-    QDir dir(m_sessionsDir, QStringLiteral("*.katesession"), QDir::Time);
-
-    for (unsigned int i = 0; i < dir.count(); ++i) {
-        QString name = dir[i];
-        name.chop(12); // .katesession
-        list << QUrl::fromPercentEncoding(name.toLatin1());
-    }
-
-    // write jump list actions to disk in the kate.desktop file
-    updateJumpListActions(list);
-
+    const QStringList list = getAllSessionsInDir(m_sessionsDir);
     bool changed = false;
-
     // Add new sessions to our list
-    for (const QString &session : qAsConst(list)) {
+    for (const QString &session : std::as_const(list)) {
         if (!m_sessions.contains(session)) {
             const QString file = sessionFileForName(session);
             m_sessions.insert(session, KateSession::create(file, session));
@@ -269,7 +276,7 @@ KateSession::Ptr KateSessionManager::giveSession(const QString &name)
     }
 
     KateSession::Ptr s = KateSession::create(sessionFileForName(name), name);
-    saveSessionTo(s->config());
+    saveSessionTo(s->config(), /*isAutoSave=*/false);
     m_sessions[name] = s;
     // Due to this add to m_sessions will updateSessionList() no signal emit,
     // but it's important to add. Otherwise could it be happen that m_activeSession
@@ -354,15 +361,17 @@ QString KateSessionManager::renameSession(KateSession::Ptr session, const QStrin
     return name;
 }
 
-void KateSessionManager::saveSessionTo(KConfig *sc)
+void KateSessionManager::saveSessionTo(KConfig *sc, bool isAutoSave)
 {
-    // Clear the session file to avoid to accumulate outdated entries
-    const auto groupList = sc->groupList();
-    for (const auto &group : groupList) {
-        // Don't delete groups for loaded documents that have
-        // ViewSpace config in session but do not have any views.
-        if (!isViewLessDocumentViewSpaceGroup(group)) {
-            sc->deleteGroup(group);
+    if (!isAutoSave) {
+        // Clear the session file to avoid to accumulate outdated entries
+        const auto groupList = sc->groupList();
+        for (const auto &group : groupList) {
+            // Don't delete groups for loaded documents that have
+            // ViewSpace config in session but do not have any views.
+            if (!isViewLessDocumentViewSpaceGroup(group)) {
+                sc->deleteGroup(group);
+            }
         }
     }
 
@@ -405,7 +414,7 @@ void KateSessionManager::saveSessionTo(KConfig *sc)
     }
 }
 
-bool KateSessionManager::saveActiveSession(bool rememberAsLast)
+bool KateSessionManager::saveActiveSession(bool rememberAsLast, bool isAutoSave)
 {
     if (!activeSession()) {
         return false;
@@ -413,7 +422,7 @@ bool KateSessionManager::saveActiveSession(bool rememberAsLast)
 
     KConfig *sc = activeSession()->config();
 
-    saveSessionTo(sc);
+    saveSessionTo(sc, isAutoSave);
 
     if (rememberAsLast && !activeSession()->isAnonymous()) {
         KSharedConfigPtr c = KSharedConfig::openConfig();
@@ -590,8 +599,14 @@ KateSessionList KateSessionManager::sessionList()
     return m_sessions.values();
 }
 
-void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
+void KateSessionManager::updateJumpListActions()
 {
+    // Let's get a list of all session we have atm
+    QStringList sessionList = getAllSessionsInDir(m_sessionsDir);
+    if (sessionList.isEmpty()) {
+        return;
+    }
+
     KService::Ptr service = KService::serviceByStorageId(qApp->desktopFileName());
     if (!service) {
         return;
@@ -613,8 +628,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
     const int maxEntryCount = std::min<int>(sessionList.count(), 10);
 
     // sessionList is ordered by time, but we like it alphabetical to avoid even more a needed update
-    QStringList sessionSubList = sessionList.mid(0, maxEntryCount);
-    sessionSubList.sort();
+    std::sort(sessionList.begin(), sessionList.begin() + maxEntryCount);
 
     // we compute the new group names in advance so we can tell whether we changed something
     // and avoid touching the desktop file leading to an expensive ksycoca recreation
@@ -623,7 +637,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
 
     for (int i = 0; i < maxEntryCount; ++i) {
         sessionActions
-            << QStringLiteral("Session %1").arg(QString::fromLatin1(QCryptographicHash::hash(sessionSubList.at(i).toUtf8(), QCryptographicHash::Md5).toHex()));
+            << QStringLiteral("Session %1").arg(QString::fromLatin1(QCryptographicHash::hash(sessionList.at(i).toUtf8(), QCryptographicHash::Md5).toHex()));
     }
 
     newActions += sessionActions;
@@ -649,7 +663,7 @@ void KateSessionManager::updateJumpListActions(const QStringList &sessionList)
 
     for (int i = 0; i < maxEntryCount; ++i) {
         const QString &action = sessionActions.at(i); // is a transform of sessionSubList, so count and order is identical
-        const QString &session = sessionSubList.at(i);
+        const QString &session = sessionList.at(i);
 
         KConfigGroup grp = df->actionGroup(action);
         grp.writeEntry("Name", session);
